@@ -39,7 +39,7 @@ use crate::{Api,
      ActivateUserResponse,
      CreateUserResponse,
      DeactivateUserResponse,
-     UpdatePasswordResponse,
+     PasswordUpdateResponse,
      UpdateUserResponse,
      QueryUserByIdResponse,
      QueryUsersResponse,
@@ -709,14 +709,14 @@ impl<S, C> Api<C> for Client<S, C> where
         }
     }
 
-    async fn update_password(
+    async fn password_update(
         &self,
         param_inline_object: models::InlineObject,
-        context: &C) -> Result<UpdatePasswordResponse, ApiError>
+        context: &C) -> Result<PasswordUpdateResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/identity-service/users/update-password",
+            "{}/mutation-api/identity-service/users/password-update",
             self.base_path
         );
 
@@ -786,14 +786,14 @@ impl<S, C> Api<C> for Client<S, C> where
                 let body = str::from_utf8(&body)
                     .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
                 let body = serde_json::from_str::<models::User>(body)?;
-                Ok(UpdatePasswordResponse::SuccessfulOperation
+                Ok(PasswordUpdateResponse::SuccessfulOperation
                     (body)
                 )
             }
             405 => {
                 let body = response.into_body();
                 Ok(
-                    UpdatePasswordResponse::InvalidInput
+                    PasswordUpdateResponse::InvalidInput
                 )
             }
             code => {
