@@ -4,7 +4,7 @@ use crate::models;
 #[cfg(any(feature = "client", feature = "server"))]
 use crate::header;
 
-/// The cognito user groups.
+/// The cognito user groups definition.
 /// Enumeration of values.
 /// Since this enum's variants do not hold data, we can easily define them them as `#[repr(C)]`
 /// which helps with FFI.
@@ -13,14 +13,14 @@ use crate::header;
 #[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, serde::Serialize, serde::Deserialize)]
 #[cfg_attr(feature = "conversion", derive(frunk_enum_derive::LabelledGenericEnum))]
 pub enum Group {
-    #[serde(rename = "ADMINGROUP")]
-    ADMINGROUP,
-    #[serde(rename = "OPERATORGROUP")]
-    OPERATORGROUP,
-    #[serde(rename = "PROFESSORGROUP")]
-    PROFESSORGROUP,
-    #[serde(rename = "STUDENTGROUP")]
-    STUDENTGROUP,
+    #[serde(rename = "ADMIN_GROUP")]
+    ADMIN_GROUP,
+    #[serde(rename = "OPERATOR_GROUP")]
+    OPERATOR_GROUP,
+    #[serde(rename = "PROFESSOR_GROUP")]
+    PROFESSOR_GROUP,
+    #[serde(rename = "STUDENT_GROUP")]
+    STUDENT_GROUP,
     #[serde(rename = "UNKNOWN")]
     UNKNOWN,
 }
@@ -28,10 +28,10 @@ pub enum Group {
 impl std::fmt::Display for Group {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match *self {
-            Group::ADMINGROUP => write!(f, "{}", "ADMINGROUP"),
-            Group::OPERATORGROUP => write!(f, "{}", "OPERATORGROUP"),
-            Group::PROFESSORGROUP => write!(f, "{}", "PROFESSORGROUP"),
-            Group::STUDENTGROUP => write!(f, "{}", "STUDENTGROUP"),
+            Group::ADMIN_GROUP => write!(f, "{}", "ADMIN_GROUP"),
+            Group::OPERATOR_GROUP => write!(f, "{}", "OPERATOR_GROUP"),
+            Group::PROFESSOR_GROUP => write!(f, "{}", "PROFESSOR_GROUP"),
+            Group::STUDENT_GROUP => write!(f, "{}", "STUDENT_GROUP"),
             Group::UNKNOWN => write!(f, "{}", "UNKNOWN"),
         }
     }
@@ -42,10 +42,10 @@ impl std::str::FromStr for Group {
 
     fn from_str(s: &str) -> std::result::Result<Self, Self::Err> {
         match s {
-            "ADMINGROUP" => std::result::Result::Ok(Group::ADMINGROUP),
-            "OPERATORGROUP" => std::result::Result::Ok(Group::OPERATORGROUP),
-            "PROFESSORGROUP" => std::result::Result::Ok(Group::PROFESSORGROUP),
-            "STUDENTGROUP" => std::result::Result::Ok(Group::STUDENTGROUP),
+            "ADMIN_GROUP" => std::result::Result::Ok(Group::ADMIN_GROUP),
+            "OPERATOR_GROUP" => std::result::Result::Ok(Group::OPERATOR_GROUP),
+            "PROFESSOR_GROUP" => std::result::Result::Ok(Group::PROFESSOR_GROUP),
+            "STUDENT_GROUP" => std::result::Result::Ok(Group::STUDENT_GROUP),
             "UNKNOWN" => std::result::Result::Ok(Group::UNKNOWN),
             _ => std::result::Result::Err(format!("Value not valid: {}", s)),
         }
@@ -422,9 +422,9 @@ pub struct User {
     #[serde(skip_serializing_if="Option::is_none")]
     pub enabled: Option<bool>,
 
-    #[serde(rename = "group")]
+    #[serde(rename = "groups")]
     #[serde(skip_serializing_if="Option::is_none")]
-    pub group: Option<Vec<models::Group>>,
+    pub groups: Option<Vec<models::Group>>,
 
 }
 
@@ -436,7 +436,7 @@ impl User {
             email: None,
             phone: None,
             enabled: None,
-            group: None,
+            groups: None,
         }
     }
 }
@@ -471,7 +471,7 @@ impl std::string::ToString for User {
             params.push(enabled.to_string());
         }
 
-        // Skipping group in query parameter serialization
+        // Skipping groups in query parameter serialization
 
         params.join(",").to_string()
     }
@@ -492,7 +492,7 @@ impl std::str::FromStr for User {
             pub email: Vec<String>,
             pub phone: Vec<String>,
             pub enabled: Vec<bool>,
-            pub group: Vec<Vec<models::Group>>,
+            pub groups: Vec<Vec<models::Group>>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -514,7 +514,7 @@ impl std::str::FromStr for User {
                     "email" => intermediate_rep.email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "phone" => intermediate_rep.phone.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "enabled" => intermediate_rep.enabled.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "group" => return std::result::Result::Err("Parsing a container in this style is not supported in User".to_string()),
+                    "groups" => return std::result::Result::Err("Parsing a container in this style is not supported in User".to_string()),
                     _ => return std::result::Result::Err("Unexpected key while parsing User".to_string())
                 }
             }
@@ -530,7 +530,7 @@ impl std::str::FromStr for User {
             email: intermediate_rep.email.into_iter().next(),
             phone: intermediate_rep.phone.into_iter().next(),
             enabled: intermediate_rep.enabled.into_iter().next(),
-            group: intermediate_rep.group.into_iter().next(),
+            groups: intermediate_rep.groups.into_iter().next(),
         })
     }
 }
