@@ -25,7 +25,7 @@ use crate::{Api,
      ActivateUserResponse,
      CreateUserResponse,
      DeactivateUserResponse,
-     UpdatePasswordResponse,
+     PasswordUpdateResponse,
      UpdateUserResponse,
      QueryUserByIdResponse,
      QueryUsersResponse,
@@ -40,7 +40,7 @@ mod paths {
             r"^/mutation-api/identity-service/users$",
             r"^/mutation-api/identity-service/users/activation$",
             r"^/mutation-api/identity-service/users/deactivation$",
-            r"^/mutation-api/identity-service/users/update-password$",
+            r"^/mutation-api/identity-service/users/password-update$",
             r"^/mutation-api/identity-service/users/(?P<id>[^/?#]*)$",
             r"^/query-api/identity-service/users$",
             r"^/query-api/identity-service/users/(?P<id>[^/?#]*)$"
@@ -50,7 +50,7 @@ mod paths {
     pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS: usize = 0;
     pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS_ACTIVATION: usize = 1;
     pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS_DEACTIVATION: usize = 2;
-    pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS_UPDATE_PASSWORD: usize = 3;
+    pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS_PASSWORD_UPDATE: usize = 3;
     pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS_ID: usize = 4;
     lazy_static! {
         pub static ref REGEX_MUTATION_API_IDENTITY_SERVICE_USERS_ID: regex::Regex =
@@ -450,8 +450,8 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                         }
             },
 
-            // UpdatePassword - PUT /mutation-api/identity-service/users/update-password
-            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_UPDATE_PASSWORD) => {
+            // PasswordUpdate - PUT /mutation-api/identity-service/users/password-update
+            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_PASSWORD_UPDATE) => {
                 {
                     let authorization = match (&context as &dyn Has<Option<Authorization>>).get() {
                         &Some(ref authorization) => authorization,
@@ -492,7 +492,7 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                                         .expect("Unable to create Bad Request response for missing body parameter InlineObject")),
                                 };
 
-                                let result = api_impl.update_password(
+                                let result = api_impl.password_update(
                                             param_inline_object,
                                         &context
                                     ).await;
@@ -511,18 +511,18 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
 
                                         match result {
                                             Ok(rsp) => match rsp {
-                                                UpdatePasswordResponse::SuccessfulOperation
+                                                PasswordUpdateResponse::SuccessfulOperation
                                                     (body)
                                                 => {
                                                     *response.status_mut() = StatusCode::from_u16(200).expect("Unable to turn 200 into a StatusCode");
                                                     response.headers_mut().insert(
                                                         CONTENT_TYPE,
                                                         HeaderValue::from_str("application/json")
-                                                            .expect("Unable to create Content-Type header for UPDATE_PASSWORD_SUCCESSFUL_OPERATION"));
+                                                            .expect("Unable to create Content-Type header for PASSWORD_UPDATE_SUCCESSFUL_OPERATION"));
                                                     let body = serde_json::to_string(&body).expect("impossible to fail to serialize");
                                                     *response.body_mut() = Body::from(body);
                                                 },
-                                                UpdatePasswordResponse::InvalidInput
+                                                PasswordUpdateResponse::InvalidInput
                                                 => {
                                                     *response.status_mut() = StatusCode::from_u16(405).expect("Unable to turn 405 into a StatusCode");
                                                 },
@@ -987,7 +987,7 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
             _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS) => method_not_allowed(),
             _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_ACTIVATION) => method_not_allowed(),
             _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_DEACTIVATION) => method_not_allowed(),
-            _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_UPDATE_PASSWORD) => method_not_allowed(),
+            _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_PASSWORD_UPDATE) => method_not_allowed(),
             _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_ID) => method_not_allowed(),
             _ if path.matched(paths::ID_QUERY_API_IDENTITY_SERVICE_USERS) => method_not_allowed(),
             _ if path.matched(paths::ID_QUERY_API_IDENTITY_SERVICE_USERS_ID) => method_not_allowed(),
@@ -1010,8 +1010,8 @@ impl<T> RequestParser<T> for ApiRequestParser {
             &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS) => Ok("CreateUser"),
             // DeactivateUser - POST /mutation-api/identity-service/users/deactivation
             &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_DEACTIVATION) => Ok("DeactivateUser"),
-            // UpdatePassword - PUT /mutation-api/identity-service/users/update-password
-            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_UPDATE_PASSWORD) => Ok("UpdatePassword"),
+            // PasswordUpdate - PUT /mutation-api/identity-service/users/password-update
+            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_PASSWORD_UPDATE) => Ok("PasswordUpdate"),
             // UpdateUser - PUT /mutation-api/identity-service/users/{id}
             &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_ID) => Ok("UpdateUser"),
             // QueryUserById - GET /query-api/identity-service/users/{id}
